@@ -49,6 +49,7 @@ class ScaleIOConnector(base.BaseLinuxConnector):
     OK_STATUS_CODE = 200
     VOLUME_NOT_MAPPED_ERROR = 84
     VOLUME_ALREADY_MAPPED_ERROR = 81
+    VOLUME_ALREADY_MAPPED_ERROR_v4 = 4037
     GET_GUID_OP_CODE = io('a', 14)
     RESCAN_VOLS_OP_CODE = io('a', 10)
 
@@ -400,7 +401,8 @@ class ScaleIOConnector(base.BaseLinuxConnector):
         if r.status_code != self.OK_STATUS_CODE:
             response = r.json()
             error_code = response['errorCode']
-            if error_code == self.VOLUME_ALREADY_MAPPED_ERROR:
+            if error_code == self.VOLUME_ALREADY_MAPPED_ERROR or \
+               error_code == self.VOLUME_ALREADY_MAPPED_ERROR_v4:
                 LOG.warning(
                     "Ignoring error mapping volume %(volume_name)s: "
                     "volume already mapped.",
@@ -537,22 +539,9 @@ class ScaleIOConnector(base.BaseLinuxConnector):
         self._rescan_vols()
         volume_paths = self.get_volume_paths(connection_properties)
         if volume_paths:
-            return self.get_device_size(volume_paths[0])
+            return utils.get_device_size(self, volume_paths[0])
 
         # if we got here, the volume is not mapped
         msg = (_("Error extending ScaleIO volume"))
         LOG.error(msg)
         raise exception.BrickException(message=msg)
-
-    def get_device_size(self, device):
-        """Get the size in bytes of a volume."""
-        (out, _err) = self._execute('blockdev', '--getsize64',
-                                    device, run_as_root=True,
-                                    root_helper=self._root_helper)
-        var = str(out.strip())
-        LOG.debug("Device %(dev)s size: %(var)s",
-                  {'dev': device, 'var': var})
-        if var.isnumeric():
-            return int(var)
-        else:
-            return None
